@@ -4,7 +4,7 @@
 
 package Syntax::Highlight::Engine::Kate::Template;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use strict;
 use Carp qw(cluck);
@@ -844,6 +844,13 @@ sub testRegExpr {
 	my $pos;
 #	my @cap = ();
 	my $sample = $$text;
+
+	# emergency measurements to avoid exception (szabgab)
+	$reg = eval { qr/$reg/ };
+	if ($@) {
+		warn $@;
+		return '';
+	}
 	if ($insensitive) {
 		if ($sample =~ /$reg/ig) {
 			$pos = pos($sample);
@@ -916,8 +923,6 @@ sub testStringDetect {
 
 __END__
 
-=cut
-
 =head1 NAME
 
 Syntax::Highlight::Engine::Kate::Template - a template for syntax highlighting plugins
@@ -1177,19 +1182,4 @@ Perl itself
 
 =head1 SEE ALSO
 
-Synax::Highlight::Engine::Kate http:://www.kate-editor.org
-
-=cut
-
-
-
-
-
-
-
-
-
-
-
-
-
+Synax::Highlight::Engine::Kate http:://www.kate-editor.org
\ No newline at end of file
